# ActionUpdateResultResource

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**id** | **str** |  | [optional] 
**outcome** | **str** |  | [optional] 
**manual_merge_required_reasons_by_property_name** | **dict(str, list[str])** |  | [optional] 
**names_of_new_parameters_missing_default_value** | **list[str]** |  | [optional] 
**removed_package_usages** | [**list[ActionUpdateRemovedPackageUsage]**](ActionUpdateRemovedPackageUsage.md) |  | [optional] 
**links** | **dict(str, str)** |  | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


